@@ -1,13 +1,18 @@
 package Date::Ethiopic::ER::tig;
 use base ( "Date::Ethiopic::ER", "Date::Ethiopic" );
+use utf8;
 
 BEGIN
 {
 	use strict;
+	use warnings;
 	use vars qw(
 		@Days
 		@ShortDays
 	);
+
+	$VERSION = "0.14";
+
 	@Days =(
 		[ "ሰንበት ዓባይ",	"Senbet Abay" ],
 		[ "ሰኖ",		"Seno"        ],
@@ -137,11 +142,6 @@ Yeha: L<http://yeha.sourceforge.net>
 Date::Ethiopic, which is distributed in the same package with
 this file.
 
-=head1 COPYRIGHT
-
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
-
-
 =head1 BUGS
 
 None presently known.
@@ -150,6 +150,13 @@ None presently known.
 
 Daniel Yacob,  L<dyacob@cpan.org|mailto:dyacob@cpan.org>
 
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (c) 2003-2025, Daniel Yacob C<< <dyacob@cpan.org> >>. All rights reserved.
+
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself. See L<perlartistic>.
+
 =head1 SEE ALSO
 
 The Yeha Project: L<http://yeha.sourceforge.net>
