@@ -1,5 +1,9 @@
 package Date::Ethiopic::ET::ti;
 use base ( "Date::Ethiopic::ti", "Date::Ethiopic::ET" );
+use strict;
+use warnings;
+
+$VERSION = "0.14";
 
 
 
@@ -74,11 +78,6 @@ Yeha: L<http://yeha.sourceforge.net>
 Date::Ethiopic, which is distributed in the same package with
 this file.
 
-=head1 COPYRIGHT
-
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
-
-
 =head1 BUGS
 
 None presently known.
@@ -87,6 +86,13 @@ None presently known.
 
 Daniel Yacob,  L<dyacob@cpan.org|mailto:dyacob@cpan.org>
 
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (c) 2003-2025, Daniel Yacob C<< <dyacob@cpan.org> >>. All rights reserved.
+
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself. See L<perlartistic>.
+
 =head1 SEE ALSO
 
 The Yeha Project: L<http://yeha.sourceforge.net>
