@@ -1,16 +1,20 @@
 package Date::Ethiopic::gez;
 use base ( "Date::Ethiopic" );
-
 use utf8;
+
 BEGIN
 {
 	use strict;
+	use warnings;
 	use vars qw(
 		@Days
 		@Months
 		@ShortDays
 		@ShortMonths
 	);
+
+	$VERSION = "0.14";
+
 	@Days =(
 		[ "አኀዱ",	"Ahadu"  ],
 		[ "ሰኑይ",	"Senuy"  ],
@@ -175,11 +179,6 @@ Yeha: L<http://yeha.sourceforge.net>
 Date::Ethiopic, which is distributed in the same package with
 this file.
 
-=head1 COPYRIGHT
-
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
-
-
 =head1 BUGS
 
 The use of "use utf8" will break for older versions of Perl.  Feel free
@@ -189,6 +188,13 @@ to comment out this line.
 
 Daniel Yacob,  L<dyacob@cpan.org|mailto:dyacob@cpan.org>
 
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (c) 2003-2025, Daniel Yacob C<< <dyacob@cpan.org> >>. All rights reserved.
+
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself. See L<perlartistic>.
+
 =head1 SEE ALSO
 
 L<Date::Ethiopic::ER::gez>    L<Date::Ethiopic::ET::gez>
